@@ -10,20 +10,22 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.01';
-$DATE = '2003/07/05';
+$VERSION = '0.02';
+$DATE = '2003/07/27';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.01 2003/07/05), 'revised 0.01'],
-    'MANIFEST' => [qw(0.01 2003/07/05), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.01 2003/07/05), 'generated, replaces 0.01'],
-    'README' => [qw(0.01 2003/07/05), 'generated, replaces 0.01'],
-    'lib/Text/Column.pm' => [qw(1.09 2003/07/05), 'revised 1.08'],
-    't/Text/Column.d' => [qw(0.03 2003/07/05), 'revised 0.02'],
-    't/Text/Column.pm' => [qw(0.03 2003/07/05), 'revised 0.02'],
-    't/Text/Column.t' => [qw(0.03 2003/07/05), 'revised 0.02'],
+    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.02 2003/07/27), 'revised 0.01'],
+    'MANIFEST' => [qw(0.02 2003/07/27), 'generated, replaces 0.01'],
+    'Makefile.PL' => [qw(0.02 2003/07/27), 'generated, replaces 0.01'],
+    'README' => [qw(0.02 2003/07/27), 'generated, replaces 0.01'],
+    'lib/Text/Column.pm' => [qw(1.09 2003/07/05), 'unchanged'],
+    't/Text/Column.d' => [qw(0.04 2003/07/27), 'revised 0.03'],
+    't/Text/Column.pm' => [qw(0.01 2003/07/05), 'unchanged'],
+    't/Text/Column.t' => [qw(0.04 2003/07/27), 'revised 0.03'],
+    'tlib/File/Package.pm' => [qw(1.1 2003/07/27), 'new'],
+    'tlib/Test/Tech.pm' => [qw(1.11 2003/07/27), 'new'],
 
 );
 
@@ -50,11 +52,11 @@ use vars qw(%INVENTORY);
 
  Text::Column - Format tables from hashes and arrays suitable for PODs
 
- Revision: -
+ Revision: A
 
- Version: 0.01
+ Version: 0.02
 
- Date: 2003/07/05
+ Date: 2003/07/27
 
  Prepared for: General Public 
 
@@ -100,7 +102,7 @@ by formatting raw array and hash data into tables for inclusion in PODS
 
 =head2 1.3 Document overview.
 
-This document releases Text::Column version 0.01
+This document releases Text::Column version 0.02
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -116,8 +118,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/Text-Column-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.01
+   http://www.softwarediamonds/packages/Text-Column-0.02
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.02
 
 
 Restrictions regarding duplication and license provisions
@@ -185,28 +187,25 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Text_Column.pm                             0.01    2003/07/05 revised 0.01
- MANIFEST                                                     0.01    2003/07/05 generated, replaces 0.01
- Makefile.PL                                                  0.01    2003/07/05 generated, replaces 0.01
- README                                                       0.01    2003/07/05 generated, replaces 0.01
- lib/Text/Column.pm                                           1.09    2003/07/05 revised 1.08
- t/Text/Column.d                                              0.03    2003/07/05 revised 0.02
- t/Text/Column.pm                                             0.03    2003/07/05 revised 0.02
- t/Text/Column.t                                              0.03    2003/07/05 revised 0.02
+ lib/Docs/Site_SVD/Text_Column.pm                             0.02    2003/07/27 revised 0.01
+ MANIFEST                                                     0.02    2003/07/27 generated, replaces 0.01
+ Makefile.PL                                                  0.02    2003/07/27 generated, replaces 0.01
+ README                                                       0.02    2003/07/27 generated, replaces 0.01
+ lib/Text/Column.pm                                           1.09    2003/07/05 unchanged
+ t/Text/Column.d                                              0.04    2003/07/27 revised 0.03
+ t/Text/Column.pm                                             0.01    2003/07/05 unchanged
+ t/Text/Column.t                                              0.04    2003/07/27 revised 0.03
+ tlib/File/Package.pm                                         1.1     2003/07/27 new
+ tlib/Test/Tech.pm                                            1.11    2003/07/27 new
 
 
 =head2 3.3 Changes
 
-The file names from 0.01 were changed as follows:
-
-  
-   return if $file =~ s=Text/Table=Text/Column=;
-
 The changes to the previous version are as follows:
 
 =over 4
 
-=item Test::STD::STDutil 0.01
+=item Test-STD-STDutil-0.01
 
 =over 4
 
@@ -228,18 +227,29 @@ created this module Test::STD::STDutil.
 
 =back
 
-=item Test::STD::STDutil 0.02
+=item Test-STD-STDutil-0.02
 
 Use the new modules from the break-up of the "File::FileUtil" module
 
-=item Text::Text 0.01
+=item Text-Text-0.01
 
 Broke up the "Test::STD::STDutil" module and moved it to more
 appropriate places in the high level directory tree.
 
-=item Text::Column 0.01
+=item Text-Column-0.01
 
-Chnaged name from Text::Table to Text::Column. Text::Table taken.
+Changed name from Text::Table to Text::Column. Text::Table taken.
+
+=item Text-Column-0.02
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
 
 =back
 
@@ -247,15 +257,6 @@ Chnaged name from Text::Table to Text::Column. Text::Table taken.
 
 This installation requires that the installation site
 has the Perl programming language installed.
-Installation sites running Microsoft Operating systems require
-the installation of Unix utilities. 
-An excellent, highly recommended Unix utilities for Microsoft
-operating systems is unxutils by Karl M. Syring.
-A copy is available at the following web sites:
-
- http://unxutils.sourceforge.net
- http://packages.SoftwareDiamnds.com
-
 There are no other additional requirements or tailoring needed of 
 configurations files, adaptation data or other software needed for this
 installation particular to any installation site.
@@ -283,16 +284,13 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Text-Column-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.01
+   http://www.softwarediamonds/packages/Text-Column-0.02
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.02
 
 
 =item Prerequistes.
 
- 'File::TestPath' => '0',
- 'File::SmartNL' => '0',
- 'File::Package' => '0',
- 'Test::Tech' => '1.08',
+ None.
 
 
 =item Security, privacy, or safety precautions.
@@ -370,7 +368,13 @@ extension for a Perl test script file
 
 =head1 2.0 SEE ALSO
 
-L<Text::Column|Text::Column>
+=over 4
+
+=item L<Text::Column|Text::Column> 
+
+=item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
+
+=back
 
 =for html
 <hr>
@@ -397,11 +401,11 @@ __DATA__
 DISTNAME: Text-Column^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.01^
+VERSION : 0.02^
 FREEZE: 1^
-PREVIOUS_DISTNAME: Text-Table^
+PREVIOUS_DISTNAME:  ^
 PREVIOUS_RELEASE: 0.01^
-REVISION: -^
+REVISION: A^
 
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -423,25 +427,17 @@ COMPRESS: gzip^
 COMPRESS_SUFFIX: gz^
 
 RESTRUCTURE:  ^
-
-CHANGE2CURRENT:  
-  return if $file =~ s=Text/Table=Text/Column=;
-^
+CHANGE2CURRENT:  ^
 
 AUTO_REVISE: 
 lib/Text/Column.pm
 t/Text/Column.*
+lib/File/Package.pm => tlib/File/Package.pm
+lib/Test/Tech.pm => tlib/Test/Tech.pm
 ^
 
-PREREQ_PM:
-'File::TestPath' => '0',
-'File::SmartNL' => '0',
-'File::Package' => '0',
-'Test::Tech' => '1.08',
-^
-
+PREREQ_PM:  ^
 TESTS: t/Text/Column.t^
-
 EXE_FILES:  ^
 
 CHANGES:
@@ -449,7 +445,7 @@ The changes to the previous version are as follows:
 
 \=over 4
 
-\=item Test::STD::STDutil 0.01
+\=item Test-STD-STDutil-0.01
 
 \=over 4
 
@@ -471,18 +467,29 @@ created this module Test::STD::STDutil.
 
 \=back
 
-\=item Test::STD::STDutil 0.02
+\=item Test-STD-STDutil-0.02
 
 Use the new modules from the break-up of the "File::FileUtil" module
 
-\=item Text::Text 0.01
+\=item Text-Text-0.01
 
 Broke up the "Test::STD::STDutil" module and moved it to more
 appropriate places in the high level directory tree.
 
-\=item Text::Column 0.01
+\=item Text-Column-0.01
 
-Chnaged name from Text::Table to Text::Column. Text::Table taken.
+Changed name from Text::Table to Text::Column. Text::Table taken.
+
+\=item Text-Column-0.02
+
+Change the test so that test support program modules resides in distribution
+directory tlib directory instead of the lib directory. 
+Because they are no longer in the lib directory, 
+test support files will not be installed as a pre-condition for the 
+test of this module.
+The test of this module will precede immediately.
+The test support files in the tlib directory will vanish after
+the installtion.
 
 \=back
 
@@ -631,12 +638,17 @@ extension for a Perl test script file
 \=back
 ^
 
-SEE_ALSO:
+SEE_ALSO: 
+\=over 4
 
-L<Text::Column|Text::Column>
+\=item L<Text::Column|Text::Column> 
 
+\=item L<Docs::US_DOD::SVD|Docs::US_DOD::SVD> 
+
+\=back
 ^
 
+
 HTML:
 <hr>
 <p><br>
